@@ -5,9 +5,10 @@ import time
 from math import ceil
 
 import terminedia.text
+import terminedia.events
 from terminedia.contexts import Context
 from terminedia.utils import contextkwords, V2, Rect, tick_forward, LazyBindProperty
-from terminedia.subpixels import BrailleChars, HalfChars
+from terminedia.subpixels import BrailleChars, HalfChars, SextantChars
 from terminedia.values import (
     CONTINUATION,
     DEFAULT_BG,
@@ -27,6 +28,8 @@ logger = logging.getLogger(__name__)
 _REPLAY = object()
 
 
+legacy_screen_draw = False
+
 class Screen:
     """Canvas class for terminal drawing.
 
@@ -54,6 +57,8 @@ class Screen:
         This does not resize the actual terminal - a smaller area is available to the methods instead.
         If given size is larger than the actual terminal, mayhen ensues.
       - clear_screen (bool): Whether to clear the terminal and hide cursor when entering the screen. Defaults to True.
+      - interactive (bool): if False, do not create binding for events, or change keyboard and mouse behaviors (used by rendering to file).
+            Default: True
 
     """
 
@@ -72,10 +77,10 @@ class Screen:
     #: Internal: tracks last used effects attribute to avoid mangling and enable optimizations
     last_effects = None
 
-    def __init__(self, size=(), clear_screen=True, backend="ansi"):
+    def __init__(self, size=(), clear_screen=True, backend="ansi", interactive=True):
+        from terminedia import context as root_context
+
         if not size:
-            #: Set in runtime to a method to retrieve the screen width, height.
-            #: The class is **not** aware of terminal resizings while running, though.
             self.get_size = lambda: V2(os.get_terminal_size())
             try:
                 size = self.get_size()
@@ -86,21 +91,22 @@ class Screen:
                         "Pass an explicit (cols, rows) size when instantiating {self.__class__}"
                     )
                 raise
+            self.dynamic_size = True
         else:
             self.get_size = lambda: V2(size)
+            self.dynamic_size = False
 
         #: Namespace to configure drawing and printing color and other parameters.
         #: Currently, the attributes that are used from here are
         #: ``color``, ``background``, ``direction``, ``effects`` and ``char``.
         self.context = Context()
 
-        #: Namespace for drawing methods, containing an instance of the :any:`Drawing` class
-        self.draw = Drawing(self.set_at, self.reset_at, self.get_size, self.context)
         self.width, self.height = self.size = size
+        self.interactive = interactive
 
         #: Namespace to allow high-resolution drawing using a :any:`HighRes` instance
         #: One should either use the public methods in HighRes or the methods on the
-        #: :any:`Drawing` instance at ``Screen.high.draw`` to do 1/4 block pixel
+        #: :any:`Drawing` instance at ``Screen.high.draw`` to do 1/2, 1/4, 1/6 and 1/8 block pixel
         #: manipulation.
         self.high = HighRes(self)
         self.braille = HighRes(
@@ -109,8 +115,11 @@ class Screen:
         self.square = HighRes(
             self, block_class=HalfChars, block_width=1, block_height=2
         )
+        self.sextant = HighRes(
+            self, block_class=SextantChars, block_width=2, block_height=3
+        )
 
-        self.text = terminedia.text.Text(self)
+        self.text = terminedia.text.TextPlane(self)
 
         self.backend = backend = backend.upper()
         if backend == "ANSI":
@@ -125,12 +134,84 @@ class Screen:
         #: various output operations in a single block that is rendered at once.
         self.commands = CommandsClass()
         self.clear_screen = clear_screen
-        self.data = FullShape.new((self.width, self.height))
+        self.shape = self.data = FullShape.new((self.width, self.height))
+        self.shape.isroot = True
+
+        #: Namespace for drawing methods, containing an instance of the :any:`Drawing` class
+        self.draw = Drawing(self.set_at, self.reset_at, self.get_at, self.get_size, self.context)
+
         # Synchronize context for data and screen painting.
         self.data.context = self.context
-        from terminedia import context
-        self.root_context = context
+        self.sprites = self.data.sprites
+        self.root_context = root_context
         self._last_setitem = 0
+        self._init_event_system()
+
+    def accelerate(self):
+        """makes drawing less interactive, but faster
+
+        Replaces the "self.draw" namespace to the one going through the
+        associated shape (self.shape) - aftewrards
+        self.update() have to be called in order to reflect any
+        drawing on the terminal, but it gets faster as updates
+        in large blocks.
+
+        Also, the "native" `self.draw` is a bit rough when it commes
+        to drawing off the screen limits.
+
+        This is called automatically by the terminedia_main loop.
+
+        There is no "de-acellarate" converse call, once an app is
+        already using screen.update it makes little sense
+        to togle back, but all one have to do if needed, is to
+        replace the attribute by a new Draw instance as created
+        inside `__init__`.
+
+        """
+        self.draw = self.shape.draw
+
+
+    def _init_event_system(self):
+        if not self.interactive:
+            return
+        self._event_subscriptions = []
+        terminedia.events._register_sigwinch()
+        self._event_subscriptions.extend([
+            terminedia.events.Subscription(
+                terminedia.events.EventTypes.TerminalSizeChange,
+                self._size_change
+            ),
+            terminedia.events.Subscription(
+                terminedia.events.EventTypes.KeyPress,
+                self._inkey_pressed_check
+            ),
+
+        ])
+        self._inkey_called_since_last_update = False
+
+    def _inkey_pressed_check(self, event):
+        # Used to mark whether `update` should call "inkey"
+        # to ensure keyboard event dispatching.
+        # This is needed because inkey consumes stdin data, and if
+        # we call it unconditionally on Screen updade, we might suppress
+        # key presses expected by applications using "terminedia.inkey" to check for
+        # input instead of using the keyboard system
+
+        self._inkey_called_since_last_update = True
+
+    def _size_change(self, event):
+        # handler - called automatically when the terminal is resized.
+        if event.type != terminedia.events.EventTypes.TerminalSizeChange:
+            return
+
+        if not self.dynamic_size:
+            # Screen size was hardcoded at screen instantiation.
+            return
+
+        self.data.resize(event.size)
+        # That is it. Other parts of the app that should be aware of screen resizing,
+        # should subscribe to the TerminalSizeChange event
+
 
     @LazyBindProperty(type=Context)
     def context(self):
@@ -141,6 +222,7 @@ class Screen:
         if self.clear_screen:
             self.commands.toggle_buffer()
         self.clear(self.clear_screen)
+
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
@@ -198,6 +280,12 @@ class Screen:
         else:
             self[pos] = self.context.char
 
+    def get_at(self, pos):
+        return self[pos]
+
+    def get_raw(self, pos):
+        return self.shape.get_raw(pos)
+
     def reset_at(self, pos):
         """Resets pixel at given coordinate
 
@@ -216,6 +304,8 @@ class Screen:
     def line_at(self, pos, length, sequence=FULL_BLOCK):
         """Renders a repeating character sequence of given length respecting the context.direction
 
+        This is an antique method from a time when there was no drawing API. Prefer
+        screen.draw.line for mor control.
         Args:
           - pos (2-sequence):  coordinates where to start drawing
           - length (int): length of character sequence to render
@@ -235,16 +325,24 @@ class Screen:
             pos += direction
 
     @contextkwords(text_attrs=True)
-    def print_at(self, pos, text):
+    def print_at(self, pos, text, size=1):
         """Positions the cursor and prints a text sequence
 
         Args:
           - pos (2-sequence): screen coordinates, (0, 0) being the top-left corner.
           - text: Text to render at position
+          - size: Text-size to print:
+                1 or "normal": plain text
+                2 or "braille": 8x8 font rendered using 2x4 Braille characters for subpixels
+                3 or "sextant": 8x8 font rendered using 2x3  Vintage Charset characters for subpixels
+                4 or "high": 8x8 font rendered using 2x2  Block characters for subpixels
+                (4,8) or "square": 8x8 font rendered using 1x2  Half-Block characters for subpixels
+                8 or "block": 8x8 font rendered using 1 Block characters as pixels
+
 
         Context's attributes are respected when printing
         """
-        self.text[1].at(pos, text)
+        self.text[size].at(pos, text)
 
     @contextkwords
     def print(self, text, **kwargs):
@@ -295,6 +393,13 @@ class Screen:
 
         """
 
+        if isinstance(value, str) and len(value) > 1:
+            # Redirect strings through the text machinery.
+            # it will separate each char in a cell, take care
+            # of double chars, embedded attributes and so on
+            self.text[1][pos] = value
+            return
+
         cls = self.__class__
         with self.lock:
             # Force underlying shape machinnery to apply context attributes and transformations:
@@ -327,8 +432,43 @@ class Screen:
         with self.commands:
             self.draw.blit(position, shape, **kwargs)
 
-    def update(self, pos1=None, pos2=None):
+    def process_events(self):
+        """Dispatches procss-wide events (like keyboard and mouse if enabled)
 
+        This will be called automatically on "self.update" - it is
+        set as a separate method because one could call this to get
+        input events before proceeding with the actual display update.
+        """
+        terminedia.events.process()
+
+    def update(self, pos1=None, pos2=None):
+        """Main method to update the display
+
+        An interactive application or animation should call this once
+        per frame to have th display contents updated on the terminal.
+
+        It can optionally update just a part of the output screen, if
+        pos1 or pos2 are given.
+
+        As of pre-0.4.0 development an app should manually provide
+        its "mainloop" and call this on each frame. Later development
+        will probably have an optional higher level loop
+        that will automate calling here.
+
+        Args:
+            - pos1, pos2: Corners of a rectangle delimitting the area to be updated.
+                (optionally, 'pos1' can be a Rect object)
+
+        """
+        tick_forward()
+
+        if self.interactive and terminedia.input.keyboard.enabled and not self._inkey_called_since_last_update:
+            # Ensure the dispatch of keypress events:
+            terminedia.inkey(consume=False)
+
+        self._inkey_called_since_last_update = False
+
+        self.process_events()
         rect = Rect(pos1, pos2)
         if rect.c2 == (0, 0) and pos2 is None:
             rect.c2 = (self.width, self.height)
@@ -341,12 +481,18 @@ class Screen:
                 for y in range(rect.top, rect.bottom):
                     for x in range(rect.left, rect.right):
                         self[x, y] = _REPLAY
-        tick_forward()
         if self.root_context.interactive_mode:
             # move cursor a couple lines from the bottom to avoid scrolling
             for i in range(3):
                 self.commands.up()
 
+    def __del__(self):
+        if not self.interactive:
+            return
+        for subscription in getattr(self, "_event_subscriptions", ()):
+            subscription.kill()
+        terminedia.events._unregister_sigwinch()
+
     def __repr__(self):
         return "".join(
             [
